@@ -2,6 +2,9 @@
 
 """第三方模块接入点"""
 
+import os
+import sys
+
 import tornado
 from tornado.web import UIModule
 from tornado import web, iostream
@@ -24,7 +27,10 @@ from thrift.transport import TSocket
 from thrift.transport import TTransport
 from thrift.protocol import TBinaryProtocol, TCompactProtocol
 
-from subprocess32 import Popen
+if sys.version_info < (3, 0):
+    from subprocess32 import Popen
+else:
+    from subprocess import Popen
 
 from docopt import docopt
 
